﻿using System;
using System.Collections.Generic;
using System.Linq;
using HealthyFood.Data;

namespace HealthyFood.Business
{
	public class Brand
	{
		private readonly HealthyFoodContext _context;
		private readonly Data.Brand _brandData;
		private readonly Producer _producer;

		internal Brand(HealthyFoodContext context, Data.Brand brandData, Producer producer)
		{
			_context = context;
			_brandData = brandData;
			_producer = producer;
		}

		public int BrandID
		{
			get { return _brandData.BrandID; }
		}

		public string Name
		{
			get { return _brandData.Name; }
		}

		public string Description
		{
			get { return _brandData.Description; }
		}

		public Producer Producer
		{
			get { return _producer; }
		}

		public IEnumerable<Product> GetProducts()
		{
			return from p in _brandData.Products
			       select new Product(_context, p, this);
		}

		public Product CreateProduct(string name, decimal energyValue,
			decimal? proteins, decimal? fats, decimal? carbohydrates)
		{
			var productData = new Data.Product();
			var product = new Product(_context, productData, this);
			product.SetProperties(name, energyValue, proteins, fats, carbohydrates);
			_brandData.Products.Add(productData);
			_context.SubmitChanges();
			return product;
		}

		public void Update(string name, string description)
		{
			SetProperties(name, description);
			_context.SubmitChanges();
		}

		internal void SetProperties(string name, string description)
		{
			if (string.IsNullOrEmpty(name))
				throw new ArgumentException("Името на марката не може да бъде празно.");

			_brandData.Name = name;
			_brandData.Description = (string.IsNullOrEmpty(description) ? null : description);
		}
	}
}
