﻿using System;
using System.Collections.Generic;
using System.Linq;
using HealthyFood.Data;

namespace HealthyFood.Business
{
	public class Producer
	{
		private readonly HealthyFoodContext _context;
		private readonly Data.Producer _producerData;

		internal Producer(HealthyFoodContext context, Data.Producer producerData)
		{
			_context = context;
			_producerData = producerData;
		}

		public int ProducerID
		{
			get { return _producerData.ProducerID; }
		}

		public string Name
		{
			get { return _producerData.Name; }
		}

		public string Country
		{
			get { return _producerData.Country; }
		}

		public string FullText
		{
			get
			{
				return (_producerData.Country == null
							? _producerData.Name
							: string.Format("{0} ({1})", _producerData.Name, _producerData.Country));
			}
		}

		public IEnumerable<Brand> GetBrands()
		{
			return from b in _producerData.Brands
			       select new Brand(_context, b, this);
		}

		public Brand CreateBrand(string name, string description)
		{
			var brandData = new Data.Brand();
			var brand = new Brand(_context, brandData, this);
			brand.SetProperties(name, description);
			_producerData.Brands.Add(brandData);
			_context.SubmitChanges();
			return brand;
		}

		public void Update(string name, string country)
		{
			SetProperties(name, country);
			_context.SubmitChanges();
		}

		internal void SetProperties(string name, string country)
		{
			if (string.IsNullOrEmpty(name))
				throw new ArgumentException("Името на производителя не може да бъде празно.");

			_producerData.Name = name;
			_producerData.Country = (string.IsNullOrEmpty(country) ? null : country);
		}
	}
}
