﻿using System;
using System.Collections.Generic;
using System.Linq;
using HealthyFood.Data;

namespace HealthyFood.Business
{
	public class Product
	{
		private readonly HealthyFoodContext _context;
		private readonly Data.Product _productData;
		private readonly Brand _brand;

		internal Product(HealthyFoodContext context, Data.Product productData, Brand brand)
		{
			_context = context;
			_productData = productData;
			_brand = brand;
		}

		public int ProductID
		{
			get { return _productData.ProductID; }
		}

		public string Name
		{
			get { return _productData.Name; }
		}

		public decimal EnergyValue
		{
			get { return _productData.EnergyValue; }
		}

		public decimal? Proteins
		{
			get { return _productData.Proteins; }
		}

		public decimal? Fats
		{
			get { return _productData.Fats; }
		}

		public decimal? Carbohydrates
		{
			get { return _productData.Carbohydrates; }
		}

		public Brand Brand
		{
			get { return _brand; }
		}

		public IEnumerable<ProductIngredient> GetIngredients()
		{
			return from pi in _productData.ProductIngredients
			       select new ProductIngredient(pi);
		}

		public void AddIngredient(int ingredientID, decimal? amount)
		{
			if (_productData.ProductIngredients.Count(pi => pi.IngredientID == ingredientID) > 0)
				throw new InvalidOperationException("Съставката вече е включена в състава на продукта.");

			Data.Ingredient ingredientData = _context.Ingredients.Single(i => i.IngredientID == ingredientID);
			var productIngredientData = new Data.ProductIngredient
			                            	{
			                            		Product = _productData,
			                            		Ingredient = ingredientData,
			                            		Amount = amount,
			                            	};
			_context.SubmitChanges();
		}

		public void RemoveIngredient(int ingredientID)
		{
			Data.ProductIngredient productIngredientData = _productData.ProductIngredients
				.SingleOrDefault(pi => pi.IngredientID == ingredientID);
			if (productIngredientData == null)
				throw new InvalidOperationException("Съставката не е включена в състава на продукта.");

			_context.ProductIngredients.DeleteOnSubmit(productIngredientData);
			_context.SubmitChanges();
		}

		public void Update(string name, decimal energyValue, decimal? proteins,
			decimal? fats, decimal? carbohydrates)
		{
			SetProperties(name, energyValue, proteins, fats, carbohydrates);
			_context.SubmitChanges();
		}

		internal void SetProperties(string name, decimal energyValue,
			decimal? proteins, decimal? fats, decimal? carbohydrates)
		{

			if (string.IsNullOrEmpty(name))
				throw new ArgumentException("Името на продукта не може да бъде празно.");

			_productData.Name = name;
			_productData.EnergyValue = energyValue;
			_productData.Proteins = proteins;
			_productData.Fats = fats;
			_productData.Carbohydrates = carbohydrates;
		}
	}
}
