﻿using System.Collections.Generic;
using System.Configuration;
using System.Linq;
using HealthyFood.Data;

namespace HealthyFood.Business
{
	public class Session
	{
		private readonly HealthyFoodContext _context;

		public Session()
		{
			string connectionString = ConfigurationManager.ConnectionStrings["connection"].ConnectionString;
			_context = new HealthyFoodContext(connectionString);
		}

		public IEnumerable<Producer> GetProducers()
		{
			return from p in _context.Producers
			       select new Producer(_context, p);
		}

		public IEnumerable<Ingredient> GetIngredients()
		{
			return from i in _context.Ingredients
			       select new Ingredient(_context, i);
		}

		public Producer CreateProducer(string name, string country)
		{
			var producerData = new Data.Producer();
			var producer = new Producer(_context, producerData);
			producer.SetProperties(name, country);
			_context.Producers.InsertOnSubmit(producerData);
			_context.SubmitChanges();
			return producer;
		}

		public Ingredient CreateIngredient(string name)
		{
			var ingredientData = new Data.Ingredient();
			var ingredient = new Ingredient(_context, ingredientData);
			ingredient.SetProperties(name);
			_context.Ingredients.InsertOnSubmit(ingredientData);
			_context.SubmitChanges();
			return ingredient;
		}
	}
}
