﻿using System.Linq;
using System.Windows.Forms;
using HealthyFood.Business;

namespace HealthyFood
{
	public partial class ProductDialog : Form
	{
		public ProductDialog()
		{
			InitializeComponent();

			Text = "Добавяне на продукт";
		}
		
		public ProductDialog(Product product)
		{
			InitializeComponent();

			Text = "Редактиране на продукт";
			tbName.Text = product.Name;
			tbEnergyValue.Text = product.EnergyValue.ToString();
			tbProteins.Text = (product.Proteins == null ? null : product.Proteins.ToString());
			tbFats.Text = (product.Fats == null ? null : product.Fats.ToString());
			tbCarbohydrates.Text = (product.Carbohydrates == null ? null : product.Carbohydrates.ToString());
			FillIngredients(product);
		}

		public new string ProductName
		{
			get { return tbName.Text; }
		}

		public decimal EnergyValue
		{
			get { return decimal.Parse(tbEnergyValue.Text); }
		}

		public decimal? Proteins
		{
			get
			{
				return (string.IsNullOrEmpty(tbProteins.Text)
							? (decimal?) null
							: decimal.Parse(tbProteins.Text));
			}
		}

		public decimal? Fats
		{
			get
			{
				return (string.IsNullOrEmpty(tbFats.Text)
							? (decimal?)null
							: decimal.Parse(tbFats.Text));
			}
		}

		public decimal? Carbohydrates
		{
			get
			{
				return (string.IsNullOrEmpty(tbCarbohydrates.Text)
							? (decimal?)null
							: decimal.Parse(tbCarbohydrates.Text));
			}
		}

		private void UpdateControls()
		{
			btnOK.Enabled = !string.IsNullOrEmpty(tbName.Text)
							&& !string.IsNullOrEmpty(tbEnergyValue.Text);
		}

		private void FillIngredients(Product product)
		{
			lbIngredients.DataSource = product.GetIngredients().ToList();
			lbIngredients.DisplayMember = "FullText";
			lbIngredients.ValueMember = "IngredientID";
		}

		private void tbName_TextChanged(object sender, System.EventArgs e)
		{
			UpdateControls();
		}

		private void tbEnergyValue_TextChanged(object sender, System.EventArgs e)
		{
			UpdateControls();
		}

		private void btnOK_Click(object sender, System.EventArgs e)
		{
			decimal value;

			if (!decimal.TryParse(tbEnergyValue.Text, out value))
			{
				MessageBox.Show("Въвели сте невалидна стойност за енергия.", "Невалидна стойност",
								MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}

			if (!string.IsNullOrEmpty(tbProteins.Text) && !decimal.TryParse(tbProteins.Text, out value))
			{
				MessageBox.Show("Въвели сте невалидна стойност за протеини.", "Невалидна стойност",
								MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}

			if (!string.IsNullOrEmpty(tbFats.Text) && !decimal.TryParse(tbFats.Text, out value))
			{
				MessageBox.Show("Въвели сте невалидна стойност за мазнини.", "Невалидна стойност",
								MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}

			if (!string.IsNullOrEmpty(tbCarbohydrates.Text) && !decimal.TryParse(tbCarbohydrates.Text, out value))
			{
				MessageBox.Show("Въвели сте невалидна стойност за въглехидрати.", "Невалидна стойност",
								MessageBoxButtons.OK, MessageBoxIcon.Error);
				return;
			}

			DialogResult = DialogResult.OK;
		}
	}
}
